@@ -41,10 +41,10 @@ my $title = 'My SDL App';
 my ( $width, $height, $depth ) = ( 640, 480, 16 );
 
 my $app = SDLx::App->new(
-    -width  => $width,
-    -height => $height,
-    -depth  => $depth,
-    -title  => $title,
+	width  => $width,
+	height => $height,
+	depth  => $depth,
+	title  => $title,
 );
 
 # your code here; remove the next line
